==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/mixin/WoodStrippingItemDrop.java <==
package net.tlotd.mixin;

import net.tlotd.block.ModBlocks;
import net.tlotd.config.ModConfigs;
import net.tlotd.item.ModItems;
import net.tlotd.util.ModTags;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static net.tlotd.block.custom.AlienControlPanelBlock.HARVESTED;

import net.minecraft.class_1269;
import net.minecraft.class_1743;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_2246;
import net.minecraft.class_2248;

@Mixin(class_1743.class)
public abstract class WoodStrippingItemDrop {

    @Inject(method = "useOnBlock", at = @At("HEAD"))
    protected void injectOnUseMethod(class_1838 context, CallbackInfoReturnable<class_1269> cir) {
        if(!context.method_8045().field_9236 && ModConfigs.AXE_STRIPPING_DROPS_BARK && context.method_8045().method_8320(context.method_8037()).method_26164(ModTags.Blocks.LOGS_WITH_BARK)) {
            class_2248 block = context.method_8045().method_8320(context.method_8037()).method_26204();
            class_1799 bark = ModItems.OAK_BARK.method_7854();
            String name = block.method_9539();
            if (block == class_2246.field_10037 || block == class_2246.field_10155) {
                bark = ModItems.SPRUCE_BARK.method_7854();
            } else if (block == class_2246.field_10511 || block == class_2246.field_10307) {
                bark = ModItems.BIRCH_BARK.method_7854();
            } else if (block == class_2246.field_10306 || block == class_2246.field_10303) {
                bark = ModItems.JUNGLE_BARK.method_7854();
            } else if (block == class_2246.field_10533 || block == class_2246.field_9999) {
                bark = ModItems.ACACIA_BARK.method_7854();
            } else if (block == class_2246.field_10010 || block == class_2246.field_10178) {
                bark = ModItems.DARK_OAK_BARK.method_7854();
            } else if (block == class_2246.field_37545 || block == class_2246.field_37549) {
                bark = ModItems.MANGROVE_BARK.method_7854();
            } else if (block == class_2246.field_42729 || block == class_2246.field_42733) {
                bark = ModItems.CHERRY_BARK.method_7854();
            } else if (block == ModBlocks.GINKGO_LOG || block == ModBlocks.GINKGO_WOOD) {
                bark = ModItems.GINKGO_BARK.method_7854();
            } else if (name.contains("aether") && (name.contains("skyroot") || name.contains("golden_oak"))) { //modded logs
                bark = ModItems.SKYROOT_BARK.method_7854();
            } else if (name.contains("alexscaves") && name.contains("pewen")) {
                bark = ModItems.PEWEN_BARK.method_7854();
            } else if (name.contains("alexscaves") && name.contains("thornwood")) {
                bark = ModItems.THORNWOOD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("fir")) {
                bark = ModItems.FIR_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("redwood")) {
                bark = ModItems.REDWOOD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("mahogany")) {
                bark = ModItems.MAHOGANY_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("jacaranda")) {
                bark = ModItems.JACARANCA_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("palm")) {
                bark = ModItems.PALM_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("willow")) {
                bark = ModItems.WILLOW_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("dead")) {
                bark = ModItems.DEAD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("magic")) {
                bark = ModItems.MAGIC_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("umbran")) {
                bark = ModItems.UMBRAN_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("hellbark")) {
                bark = ModItems.HELLBARK_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("ancient")) {
                bark = ModItems.ASHEN_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("azalea")) {
                bark = ModItems.AZALEA_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("blossom")) {
                bark = ModItems.TRUMPET_BARK.method_7854();
            } else if (name.contains("thermal") && name.contains("rubberwood")) {
                bark = ModItems.RUBBERWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("twilight_oak")) {
                bark = ModItems.TWILIGHT_OAK_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("canopy")) {
                bark = ModItems.CANOPY_TREE_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("mangrove")) {
                bark = ModItems.TWILIGHT_MANGROVE_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("dark")) {
                bark = ModItems.DARKWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("time")) {
                bark = ModItems.TIMEWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("transformation")) {
                bark = ModItems.TRANSWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("mining")) {
                bark = ModItems.MINEWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("sorting")) {
                bark = ModItems.SORTINGWOOD_BARK.method_7854();
            }
            class_2248.method_9577(context.method_8045(), context.method_8037(), bark);
        }
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/mixin/WoodStrippingItemDrop.java <==
package net.tlotd.mixin;

import net.tlotd.block.ModBlocks;
import net.tlotd.config.ModConfigs;
import net.tlotd.item.ModItems;
import net.tlotd.util.ModTags;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static net.tlotd.block.custom.AlienControlPanelBlock.HARVESTED;

import net.minecraft.class_1269;
import net.minecraft.class_1743;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_2246;
import net.minecraft.class_2248;

@Mixin(class_1743.class)
public abstract class WoodStrippingItemDrop {

    @Inject(method = "useOnBlock", at = @At("HEAD"))
    protected void injectOnUseMethod(class_1838 context, CallbackInfoReturnable<class_1269> cir) {
        if(!context.method_8045().field_9236 && ModConfigs.AXE_STRIPPING_DROPS_BARK && context.method_8045().method_8320(context.method_8037()).method_26164(ModTags.Blocks.LOGS_WITH_BARK)) {
            class_2248 block = context.method_8045().method_8320(context.method_8037()).method_26204();
            class_1799 bark = ModItems.OAK_BARK.method_7854();
            String name = block.method_9539();
            if (block == class_2246.field_10037 || block == class_2246.field_10155) {
                bark = ModItems.SPRUCE_BARK.method_7854();
            } else if (block == class_2246.field_10511 || block == class_2246.field_10307) {
                bark = ModItems.BIRCH_BARK.method_7854();
            } else if (block == class_2246.field_10306 || block == class_2246.field_10303) {
                bark = ModItems.JUNGLE_BARK.method_7854();
            } else if (block == class_2246.field_10533 || block == class_2246.field_9999) {
                bark = ModItems.ACACIA_BARK.method_7854();
            } else if (block == class_2246.field_10010 || block == class_2246.field_10178) {
                bark = ModItems.DARK_OAK_BARK.method_7854();
            } else if (block == class_2246.field_37545 || block == class_2246.field_37549) {
                bark = ModItems.MANGROVE_BARK.method_7854();
            } else if (block == class_2246.field_42729 || block == class_2246.field_42733) {
                bark = ModItems.CHERRY_BARK.method_7854();
            } else if (block == ModBlocks.GINKGO_LOG || block == ModBlocks.GINKGO_WOOD) {
                bark = ModItems.GINKGO_BARK.method_7854();
            } else if (name.contains("aether") && (name.contains("skyroot") || name.contains("golden_oak"))) { //modded logs
                bark = ModItems.SKYROOT_BARK.method_7854();
            } else if (name.contains("alexscaves") && name.contains("pewen")) {
                bark = ModItems.PEWEN_BARK.method_7854();
            } else if (name.contains("alexscaves") && name.contains("thornwood")) {
                bark = ModItems.THORNWOOD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("fir")) {
                bark = ModItems.FIR_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("pine")) {
                bark = ModItems.PINE_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("maple")) {
                bark = ModItems.MAPLE_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("redwood")) {
                bark = ModItems.REDWOOD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("mahogany")) {
                bark = ModItems.MAHOGANY_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("jacaranda")) {
                bark = ModItems.JACARANCA_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("palm")) {
                bark = ModItems.PALM_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("willow")) {
                bark = ModItems.WILLOW_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("dead")) {
                bark = ModItems.DEAD_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("magic")) {
                bark = ModItems.MAGIC_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("umbran")) {
                bark = ModItems.UMBRAN_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("hellbark")) {
                bark = ModItems.HELLBARK_BARK.method_7854();
            } else if (name.contains("biomesoplenty") && name.contains("empyreal")) {
                bark = ModItems.EMPYREAL_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("ancient")) {
                bark = ModItems.ASHEN_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("azalea")) {
                bark = ModItems.AZALEA_BARK.method_7854();
            } else if (name.contains("quark") && name.contains("blossom")) {
                bark = ModItems.TRUMPET_BARK.method_7854();
            } else if (name.contains("thermal") && name.contains("rubberwood")) {
                bark = ModItems.RUBBERWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("twilight_oak")) {
                bark = ModItems.TWILIGHT_OAK_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("canopy")) {
                bark = ModItems.CANOPY_TREE_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("mangrove")) {
                bark = ModItems.TWILIGHT_MANGROVE_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("dark")) {
                bark = ModItems.DARKWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("time")) {
                bark = ModItems.TIMEWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("transformation")) {
                bark = ModItems.TRANSWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("mining")) {
                bark = ModItems.MINEWOOD_BARK.method_7854();
            } else if (name.contains("twilightforest") && name.contains("sorting")) {
                bark = ModItems.SORTINGWOOD_BARK.method_7854();
            }
            class_2248.method_9577(context.method_8045(), context.method_8037(), bark);
        }
    }
}
